==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/static_seo_urls.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   static_seo_urls.lang.inc.php 2018-10-24
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2017 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
	'CHANGEFREQ'                                => 'Änderungsfrequenz in der Sitemap',
	'CHANGEFREQ_ALWAYS'                         => 'immer',
	'CHANGEFREQ_DAILY'                          => 'täglich',
	'CHANGEFREQ_HOURLY'                         => 'stündlich',
	'CHANGEFREQ_MONTHLY'                        => 'monatlich',
	'CHANGEFREQ_NEVER'                          => 'niemals',
	'CHANGEFREQ_WEEKLY'                         => 'wöchentlich',
	'CHANGEFREQ_YEARLY'                         => 'jährlich',
	'CONTENT_MANAGER'                           => 'Content Manager',
	'DELETE_STATIC_SEO_URL_ERROR_TEXT'          => 'Die gewählte statische Seite konnte leider nicht gelöscht werden.',
	'DELETE_STATIC_SEO_URL_ERROR_TITLE'         => 'Die statische Seite konnte nicht gelöscht werden',
	'DELETE_STATIC_SEO_URL_MODAL_TEXT'          => 'Sind Sie sicher, dass Sie den Eintrag für die Statische Seite löschen wollen?',
	'DELETE_STATIC_SEO_URL_MODAL_TITLE'         => 'Statische Seite löschen',
	'DESCRIPTION'                               => 'Meta Description',
	'FORM_SUBMIT_ERROR_MODAL_TEXT'              => 'Die statische Seite konnte nicht gespeichert werden. Bitte überprüfen Sie die Angaben und versuchen Sie es erneut.',
	'FORM_SUBMIT_ERROR_MODAL_TITLE'             => 'Fehler beim Speichern der statischen Seite',
	'KEYWORDS'                                  => 'Meta Keywords',
	'MASTER_DATA'                               => 'Stammdaten',
	'NAME'                                      => 'Name',
	'NO_ENTRIES'                                => 'Keine Einträge',
	'OGIMAGE'                                   => 'Bild für soziale Medien (og:image)',
	'OGIMAGE_DELETE'                            => 'Bild löschen',
	'OGIMAGE_FILEMANAGER_ONLY'                  => 'erfordert Dateimanager',
	'PAGE_TITLE'                                => 'Statische Seiten',
	'PRIORITY'                                  => 'Priorität in der Sitemap',
	'PRODUCTS_CONTENT'                          => 'Artikel Content',
	'ROBOTS_ENTRY'                              => 'Eintrag in robots.txt (disallow)',
	'ROBOTS_ENTRY_OVERVIEW'                     => 'Robots-Disallow',
	'SEO_DATA'                                  => 'SEO Daten',
	'SITEMAP_ENTRY'                             => 'In die Sitemap aufnehmen',
	'SITEMAP_ENTRY_OVERVIEW'                    => 'Sitemap',
	'STATIC_SEO_URL_CHECKBOX_ERROR_TEXT'        => 'Bei der Status-Änderung der statischen Seite ist ein Fehler aufgetreten.',
	'STATIC_SEO_URL_CHECKBOX_ERROR_TITLE'       => 'Es ist ein Fehler aufgetreten',
	'STATIC_SEO_URL_CONTENT_CREATE_BUTTON_TEXT' => 'Inhalt hinzufügen',
	'TITLE'                                     => 'Meta Title',
];

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/static_seo_urls.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   static_seo_urls.lang.inc.php 2018-10-24
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2017 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
	'CHANGEFREQ'                                => 'Änderungsfrequenz in der Sitemap',
	'CHANGEFREQ_ALWAYS'                         => 'immer',
	'CHANGEFREQ_DAILY'                          => 'täglich',
	'CHANGEFREQ_HOURLY'                         => 'stündlich',
	'CHANGEFREQ_MONTHLY'                        => 'monatlich',
	'CHANGEFREQ_NEVER'                          => 'niemals',
	'CHANGEFREQ_WEEKLY'                         => 'wöchentlich',
	'CHANGEFREQ_YEARLY'                         => 'jährlich',
	'CONTENT_MANAGER'                           => 'Content Manager',
	'DELETE_STATIC_SEO_URL_ERROR_TEXT'          => 'Die gewählte statische Seite konnte leider nicht gelöscht werden.',
	'DELETE_STATIC_SEO_URL_ERROR_TITLE'         => 'Die statische Seite konnte nicht gelöscht werden',
	'DELETE_STATIC_SEO_URL_MODAL_TEXT'          => 'Bist du sicher, dass du den Eintrag für die Statische Seite löschen willst?',
	'DELETE_STATIC_SEO_URL_MODAL_TITLE'         => 'Statische Seite löschen',
	'DESCRIPTION'                               => 'Meta Description',
	'FORM_SUBMIT_ERROR_MODAL_TEXT'              => 'Die statische Seite konnte nicht gespeichert werden. Bitte überprüfe die Angaben und versuche es erneut.',
	'FORM_SUBMIT_ERROR_MODAL_TITLE'             => 'Fehler beim Speichern der statischen Seite',
	'KEYWORDS'                                  => 'Meta Keywords',
	'MASTER_DATA'                               => 'Stammdaten',
	'NAME'                                      => 'Name',
	'NO_ENTRIES'                                => 'Keine Einträge',
	'OGIMAGE'                                   => 'Bild für soziale Medien (og:image)',
	'OGIMAGE_DELETE'                            => 'Bild löschen',
	'OGIMAGE_FILEMANAGER_ONLY'                  => 'erfordert Dateimanager',
	'PAGE_TITLE'                                => 'Statische Seiten',
	'PRIORITY'                                  => 'Priorität in der Sitemap',
	'PRODUCTS_CONTENT'                          => 'Artikel Content',
	'ROBOTS_ENTRY'                              => 'Eintrag in robots.txt (disallow)',
	'ROBOTS_ENTRY_OVERVIEW'                     => 'Robots-Disallow',
	'SEO_DATA'                                  => 'SEO-Daten',
	'SITEMAP_ENTRY'                             => 'In die Sitemap aufnehmen',
	'SITEMAP_ENTRY_OVERVIEW'                    => 'Sitemap',
	'STATIC_SEO_URL_CHECKBOX_ERROR_TEXT'        => 'Bei der Status-Änderung der statischen Seite ist ein Fehler aufgetreten.',
	'STATIC_SEO_URL_CHECKBOX_ERROR_TITLE'       => 'Es ist ein Fehler aufgetreten',
	'STATIC_SEO_URL_CONTENT_CREATE_BUTTON_TEXT' => 'Inhalt hinzufügen',
	'TITLE'                                     => 'Meta Title',
];
